@@ -123,8 +123,8 @@ class WOQLQuery:
                         c = {"@value": c}
                     clauses.append({'as': [c, v]})
                 else:
-                    if hasattr(a, 'as') or ('as' in a):
-                        clauses.append(v)
+                    if hasattr(v, 'woql_as') or ('as' in v):
+                        clauses += v.json()
                     else:
                         clauses.append({'as': [v]})
         return clauses
@@ -206,13 +206,12 @@ class WOQLQuery:
         self.cursor['length'] = [va, vb];
         return self
 
-    def remote(self, json, opts=None):
+    def remote(self, url, opts=None):
         """Provides details of a remote data source in a JSON format that includes a URL property
 
         Parameters
         ----------
-        json : dict
-            remote data source in a JSON format
+        url : remote data source url
         opts : input options, optional
 
         Returns
@@ -221,19 +220,18 @@ class WOQLQuery:
             query object that can be chained and/or execute
         """
         if opts is not None:
-            self.cursor['remote'] = [json, opts]
-        self.cursor['remote'] = [json];
+            self.cursor['remote'] = [url, opts]
+        else:
+            self.cursor['remote'] = [url]
         return self
 
-    def post(self, json, fileName, opts=None):
+    def post(self, field, opts=None):
         """Provides details of a file source in a JSON format that includes a URL property
 
         Parameters
         ----------
-        json : dict
-            file data source in a JSON format
         fileName : str
-            the file's name
+            field
         opts : input options, optional
 
         Returns
@@ -242,8 +240,9 @@ class WOQLQuery:
             query object that can be chained and/or execute
         """
         if opts is not None:
-            self.cursor['post'] = [json, fileName,opts]
-        self.cursor['post'] = [json, fileName];
+            self.cursor['post'] = [field, opts]
+        else:
+            self.cursor['post'] = [field]
         return self
 
 
@@ -263,7 +262,8 @@ class WOQLQuery:
         """
         if opts is not None:
             self.cursor['file'] = [json, opts]
-        self.cursor['file'] = [json];
+        else:
+            self.cursor['file'] = [json]
         return self
 
     def group_by(self, gvarlist, groupedvar, groupquery, output=None):
@@ -473,12 +473,12 @@ class WOQLQuery:
         self.cursor['re'] = [pattern, test, matches]
         return self
 
-    def concat(self, list, v):
+    def concat(self, lst, v):
         """Concatenates the list of variables into a string and saves the result in v
 
         Parameters
         ----------
-        list : list
+        lst : list
             list of variables to concatenate
         v : str
             saves the results
@@ -488,17 +488,17 @@ class WOQLQuery:
         WOQLQuery object
             query object that can be chained and/or execute
         """
-        if type(list) == str:
-            nlist = re.split('(v:[\w_]+)\\b', list)
+        if type(lst) == str:
+            nlist = re.split('(v:[\w_]+)\\b', lst)
             for i in range(1,len(nlist)):
                 if (nlist[i-1][len(nlist[i-1])-1:] == "v") and \
                    (nlist[i][:1] == ":"):
                    nlist[i-1] = nlist[i-1][:len(nlist[i-1])-1]
                    nlist[i] = nlist[i][1:]
-        elif 'list' in list:
-            nlist = list['list']
-        elif isinstance(list, (list, dict, WOQLQuery)):
-            nlist = list
+        elif 'list' in lst:
+            nlist = lst['list']
+        elif isinstance(lst, (list, dict, WOQLQuery)):
+            nlist = lst
         args = []
         for item in nlist:
             if (not item):
@@ -510,7 +510,7 @@ class WOQLQuery:
                     nvalue = {"@value": item, "@type": "xsd:string"}
                     args.append(nvalue)
             elif item:
-                args.append(nlist[i])
+                args.append(item)
 
         if v.find(":") == -1:
             v = "v:" + v
@@ -670,6 +670,7 @@ class WOQLQuery:
         if json:
             self.query = json
             return self
+
         return self.query
 
     def when(self, Query, Update=None):
